summaryrefslogtreecommitdiff
path: root/Echolot/Config.pm
diff options
context:
space:
mode:
authorPeter Palfrader <peter@palfrader.org>2003-02-16 09:09:57 +0000
committerPeter Palfrader <peter@palfrader.org>2003-02-16 09:09:57 +0000
commit04265aabca9e8d0dadd4efb8d194e9d679df1c6d (patch)
tree0d6446847c2b265e835bba5d1c1c925712997b59 /Echolot/Config.pm
parent88e90e95c7b92268618c2ed62b7621b03c77fc26 (diff)
Ping broken chains more often ("Intensive Care")
Expire chainpings
Diffstat (limited to 'Echolot/Config.pm')
-rw-r--r--Echolot/Config.pm5
1 files changed, 3 insertions, 2 deletions
diff --git a/Echolot/Config.pm b/Echolot/Config.pm
index 89b33ae..b9522f6 100644
--- a/Echolot/Config.pm
+++ b/Echolot/Config.pm
@@ -1,7 +1,7 @@
package Echolot::Config;
# (c) 2002 Peter Palfrader <peter@palfrader.org>
-# $Id: Config.pm,v 1.52 2003/02/16 05:46:54 weasel Exp $
+# $Id: Config.pm,v 1.53 2003/02/16 09:09:57 weasel Exp $
#
=pod
@@ -100,7 +100,8 @@ sub init($) {
ping_every_nth_time => 48, # send out pings to the same remailer every 48 calls, i.e. every 4 hours
chainpinger_interval => 5*60, # send out pings every 5 minutes
- chainping_every_nth_time => 810, # send out pings to the same chain every 810 calls, i.e. every 3 days
+ chainping_every_nth_time => 864, # send out pings to the same chain every 864 calls, i.e. every 3 days
+ chainping_ic_every_nth_time => 810, # send out pings to broken or unknown chains every 288 calls, i.e. every day
chainping_period => 10*24*60*60, # 12 days
chainping_fudge => 0.3, # if less than 0.3 * rel1 * rel2 make it, the chain is really broken
chainping_grace => 1.5, # don't count pings sent no longer than 1.5 * (lat1 + lat2) ago